@@ -106,7 +106,7 @@ class MainScreen(Screen):
         self.grid_layout.add_widget(start_discord_bot_button)
         self.add_widget(self.grid_layout)
 
-        if platform.node().lower() in SERVER:
+        if platform.node().lower() in SERVER or f"{platform.node().lower()}.local" in SERVER:
             self.start_api_server(start_api_server_button)
             self.start_discord_bot(start_discord_bot_button)
 
@@ -219,9 +219,7 @@ class LabelPrinterScreen(Screen):
 
         main_grid.add_widget(label_grid)
 
-        main_grid.slide_label_printer_button = Button(
-            text="Back to main screen", size_hint=(1, 0.1)
-        )
+        main_grid.slide_label_printer_button = Button(text="Back to main screen", size_hint=(1, 0.1))
         main_grid.slide_label_printer_button.bind(on_press=self.changer)
         main_grid.add_widget(main_grid.slide_label_printer_button)
 
@@ -264,13 +262,7 @@ class LabelPrinterScreen(Screen):
         quantity = int(self.quantity_textbox.text)
 
         Thread(
-            target=partial(
-                label_print.print_text,
-                text,
-                quantity=quantity,
-                print_date=self.date_checkbox.active,
-                barcode=barcode,
-            )
+            target=partial(label_print.print_text, text, quantity=quantity, print_date=self.date_checkbox.active, barcode=barcode)
         ).start()
         self.barcode_textbox.text = "Barcode"
         self.quantity_textbox.text = "1"
